@@ -621,8 +621,9 @@ qreal Icon::paintedHeight() const
 
 QSize Icon::iconSizeHint() const
 {
-    // size hint is always square, non square case in updatePaintGeometry
-    if (m_roundToIconSize && m_units) {
+    if (!m_roundToIconSize) {
+        return QSize(width(), height());
+    } else if (m_units) {
         return QSize(m_units->iconSizes()->roundedIconSize(std::min(width(), height())), m_units->iconSizes()->roundedIconSize(std::min(width(), height())));
     } else {
         return QSize(std::min(width(), height()), std::min(width(), height()));
@@ -658,7 +659,7 @@ void Icon::updatePaintedGeometry()
                 newSize = QSizeF(roundedWidth, roundedWidth);
             }
         } else {
-            const QSizeF iconPixSize(m_icon.width() / m_devicePixelRatio, m_icon.width() / m_devicePixelRatio);
+            const QSizeF iconPixSize(m_icon.width() / m_devicePixelRatio, m_icon.height() / m_devicePixelRatio);
 
             const qreal w = widthValid() ? width() : iconPixSize.width();
             const qreal widthScale = w / iconPixSize.width();
