@@ -698,6 +698,21 @@ void PlatformTheme::setSmallFont(const QFont &font)
     }
 }
 
+qreal PlatformTheme::frameContrast() const
+{
+    // This value must be kept in sync with
+    // the value from Breeze Qt Widget theme.
+    // See: https://invent.kde.org/plasma/breeze/-/blob/master/kstyle/breezemetrics.h?ref_type=heads#L162
+    return 0.20;
+}
+
+qreal PlatformTheme::lightFrameContrast() const
+{
+    // This can be utilized to return full contrast
+    // if high contrast accessibility setting is enabled
+    return frameContrast() / 2.0;
+}
+
 // setters for QML clients
 void PlatformTheme::setCustomTextColor(const QColor &color)
 {
